@@ -1,6 +1,6 @@
 
 CorDdPlot = function(x, d, ncode) {
-    data = COR_DeltaDd(x, d, ncode)
+    data = COR_DeltaDd(x, d, ncode,nrepet=999)
    # requireNamespace("ggplot2")
      a= plot(data$Dgeo, data$PairwiseDeltaD, xlab = "Geographic Distance", ylab = "Genetic differentiation (DeltaD)")
     abline(lm(data$PairwiseDeltaD ~ data$Dgeo))
